@@ -1,7 +1,7 @@
-# encoding: utf-8
-#
+# frozen_string_literal: true
+
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,6 +18,14 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 module ImportsHelper
+  def import_title
+    l(:"label_import_#{import_partial_prefix}")
+  end
+
+  def import_partial_prefix
+    @import.class.name.sub('Import', '').underscore.pluralize
+  end
+
   def options_for_mapping_select(import, field, options={})
     tags = "".html_safe
     blank_text = options[:required] ? "-- #{l(:actionview_instancetag_blank_option)} --" : "&nbsp;".html_safe
@@ -25,7 +33,7 @@ module ImportsHelper
     tags << options_for_select(import.columns_options, import.mapping[field])
     if values = options[:values]
       tags << content_tag('option', '--', :disabled => true)
-      tags << options_for_select(values.map {|text, value| [text, "value:#{value}"]}, import.mapping[field])
+      tags << options_for_select(values.map {|text, value| [text, "value:#{value}"]}, import.mapping[field] || options[:default_value])
     end
     tags
   end
@@ -38,7 +46,7 @@ module ImportsHelper
   # Returns the options for the date_format setting
   def date_format_options
     Import::DATE_FORMATS.map do |f|
-      format = f.gsub('%', '').gsub(/[dmY]/) do
+      format = f.delete('%').gsub(/[dmY]/) do
         {'d' => 'DD', 'm' => 'MM', 'Y' => 'YYYY'}[$&]
       end
       [format, f]
